@@ -642,6 +642,7 @@ class CallBuilder(StructureBuilder):
                     self.def_subs)[1]
                 expression = f"xr.DataArray({expression}, {subs}, "\
                     f"{list(self.def_subs)})"
+            calls["time"] = 1
 
         elif self.function == "active_initial":
             # Ee need to ensure that active initial outputs are always the
@@ -655,6 +656,10 @@ class CallBuilder(StructureBuilder):
             }
 
             calls = {name: 1}
+
+        elif self.function == "elmcount":
+            final_subscripts = {}
+
         else:
             final_subscripts = self.reorder(arguments)
             if self.function == "xidz" and final_subscripts:
@@ -1190,6 +1195,7 @@ class IntegBuilder(StructureBuilder):
             "flow": integ_str.flow,
             "initial": integ_str.initial
         }
+        self.non_negative = integ_str.non_negative
 
     def build(self, arguments: dict) -> BuildAST:
         """
@@ -1208,7 +1214,6 @@ class IntegBuilder(StructureBuilder):
         """
         self.component.type = "Stateful"
         self.component.subtype = "Integ"
-        self.section.imports.add("statefuls", "Integ")
 
         arguments["initial"].reshape(
             self.section.subscripts, self.def_subs, True)
@@ -1219,11 +1224,24 @@ class IntegBuilder(StructureBuilder):
             self.element.identifier, prefix="_integ")
 
         # Create the object
-        self.element.objects[arguments["name"]] = {
-            "name": arguments["name"],
-            "expression": "%(name)s = Integ(lambda: %(flow)s, "
-                          "lambda: %(initial)s, '%(name)s')" % arguments
-        }
+        if self.non_negative:
+            # Non-negative stocks
+            self.section.imports.add("statefuls", "NonNegativeInteg")
+            self.element.objects[arguments["name"]] = {
+                "name": arguments["name"],
+                "expression": "%(name)s = NonNegativeInteg("
+                              "lambda: %(flow)s, "
+                              "lambda: %(initial)s, '%(name)s')" % arguments
+            }
+        else:
+            # Regular stocks
+            self.section.imports.add("statefuls", "Integ")
+            self.element.objects[arguments["name"]] = {
+                "name": arguments["name"],
+                "expression": "%(name)s = Integ(lambda: %(flow)s, "
+                              "lambda: %(initial)s, '%(name)s')" % arguments
+            }
+
         # Add other dependencies
         self.element.other_dependencies[arguments["name"]] = {
             "initial": arguments["initial"].calls,
@@ -1998,7 +2016,7 @@ class ArrayBuilder(StructureBuilder):
             threshold=np.prod(self.value.shape)
         )
         self.component.type = "Constant"
-        self.component.subtype = "Normal"
+        self.component.subtype = self.component.subtype or "Normal"
 
         final_subs, subscripts_out =\
             self.section.subscripts.simplify_subscript_input(
