@@ -5,7 +5,9 @@ functionspace = {
     "elmcount": ("len(%(0)s)", None),
 
     # directly build numpy based functions
+    "pi": ("np.pi", ("numpy",)),
     "abs": ("np.abs(%(0)s)", ("numpy",)),
+    "power": ("np.power(%(0)s,%(1)s)", ("numpy",)),
     "min": ("np.minimum(%(0)s, %(1)s)", ("numpy",)),
     "max": ("np.maximum(%(0)s, %(1)s)", ("numpy",)),
     "exp": ("np.exp(%(0)s)", ("numpy",)),
@@ -33,6 +35,8 @@ functionspace = {
     "sum": ("sum(%(0)s, dim=%(axis)s)", ("functions", "sum")),
     "vmax": ("vmax(%(0)s, dim=%(axis)s)", ("functions", "vmax")),
     "vmin": ("vmin(%(0)s, dim=%(axis)s)", ("functions", "vmin")),
+    "vmax_xmile": ("vmax(%(0)s)", ("functions", "vmax")),
+    "vmin_xmile": ("vmin(%(0)s)", ("functions", "vmin")),
     "vector_select": (
         "vector_select(%(0)s, %(1)s, %(axis)s, %(2)s, %(3)s, %(4)s)",
         ("functions", "vector_select")
