@@ -13,14 +13,14 @@ from pysd.py_backend.model import Model
 if sys.version_info[:2] < (3, 7):  # pragma: no cover
     raise RuntimeError(
         "\n\n"
-        + "Your Python version is not longer supported by PySD.\n"
+        + "Your Python version is no longer supported by PySD.\n"
         + "The current version needs to run at least Python 3.7."
         + " You are running:\n\tPython "
         + sys.version
         + "."
         + "\nPlease update your Python version or use the last "
         + " supported version:\n\t"
-        + "https://github.com/JamesPHoughton/pysd/releases/tag/LastPy2"
+        + "https://github.com/SDXorg/pysd/releases/tag/LastPy2"
     )
 
 
@@ -42,7 +42,7 @@ def read_xmile(xmile_file, data_files=None, initialize=True,
         If given the list of files where the necessary data to run the model
         is given. Default is None.
 
-    missing_values : str ("warning", "error", "ignore", "keep") (optional)
+    missing_values: str ("warning", "error", "ignore", "keep") (optional)
         What to do with missing values. If "warning" (default)
         shows a warning message and interpolates the values.
         If "raise" raises an error. If "ignore" interpolates
