@@ -1,7 +1,7 @@
 """
 The Element class allows parsing the LHS of a model equation.
 Depending on the LHS value, either a SubscriptRange object or a Component
-object will be returned. There are 4 components types:
+object will be returned. There are four components types:
 
 - Component: Regular component, defined with '='.
 - UnchangeableConstant: Unchangeable constant, defined with '=='.
@@ -777,6 +777,12 @@ class EquationVisitor(parsimonious.NodeVisitor):
         else:
             return self.add_element(eval(n.text))
 
+    def visit_tabbed_array_call(self, n, vc):
+        return self.add_element(np.array(vc[4], dtype=float))
+
+    def visit_array_tabbed(self, n, vc):
+        return n.text.strip().split()
+
     def visit_subscript_list(self, n, vc):
         subs = [x.strip() for x in vc[2].split(",")]
         self.subs = structures["subscripts_ref"](subs)
